# WORST CHATROOM EVER

> _**Telegram killer**_.
>>The New York Times

> _**Undeniable ease and convenience of use**_.
>> Pavel Du Rove

> _**)))**_.
>> Anonymous


## Screenshots

![chatshit](./screenshots/example1.png "chatshit1")
![chatshit](./screenshots/example2.png "chatshit2")
![chatshit](./screenshots/example3.png "chatshit3")
